# TheFloatingDutchman
The Floating Dutchman is a Rouguelike, Shoot-Em-Up game where you play as the captain of The Flying Dutchman and you've just been lost in space. Travel the galaxies in search of your missing crew members while fighting off the waves of Ghost Bustas as they try and stop you.

## Version Control
https://github.com/EddieFerro/thefloatingdutchman

## Installing package through pip
#### Ensure you have the latest python installed (3.8.3) and pip

Python: https://www.python.org/downloads/  
Pip: https://pip.pypa.io/en/stable/installing/

#### Run the following command in the terminal to install the game and its dependencies:    
`pip install TheFloatingDutchman`
**or**
`pip install TheFloatingDutchman==0.0.7`

## Installing from source
#### Ensure you have the latest python installed (3.8.3) and pip

Python: https://www.python.org/downloads/  
Pip: https://pip.pypa.io/en/stable/installing/

#### Then clone the repository
    
    git clone https://github.com/EddieFerro/thefloatingdutchman.git

#### And install dependencies

    python3 -m pip install -U pygame==2.0.0.dev8 --user  
    python3 -m pip install -U networkx --user  
    python3 -m pip install -U numpy --user

## Running the game
#### If installed through pip type the following command into the terminal:

    TheFloatingDutchman

#### If installed from source, in the same directory as main run the following command:

    python3 main.py
